diff --git a/indra/newview/llthumbnailctrl.cpp b/indra/newview/llthumbnailctrl.cpp
index 340dba37171440a3923c61bb9369bb73f0158d78..04130fc724d755b2bce5c48a90d845629c63e006 100644
--- a/indra/newview/llthumbnailctrl.cpp
+++ b/indra/newview/llthumbnailctrl.cpp
@@ -100,7 +100,8 @@ void LLThumbnailCtrl::draw()
     {
         if( mTexturep->getComponents() == 4 )
         {
-            gl_rect_2d_checkerboard( draw_rect, alpha );
+            const LLColor4 color(.098f, .098f, .098f);
+            gl_rect_2d( draw_rect, color, TRUE);
         }
         
         gl_draw_scaled_image( draw_rect.mLeft, draw_rect.mBottom, draw_rect.getWidth(), draw_rect.getHeight(), mTexturep, UI_VERTEX_COLOR % alpha);
diff --git a/indra/newview/llinventoryobserver.cpp b/indra/newview/llinventoryobserver.cpp
index 0b0252824659a8b4f5dff7d935d7ceb96cc3ce5f..0d96c7a0056fc9aba5de8284a391a8132d27a34d 100644
--- a/indra/newview/llinventoryobserver.cpp
+++ b/indra/newview/llinventoryobserver.cpp
@@ -266,8 +266,8 @@ void LLInventoryFetchItemsObserver::startFetch()
 
 	LLSD items_llsd;
 
-    typedef std::map<LLUUID, uuid_vec_t> requests_by_fodlers_t;
-    requests_by_fodlers_t requests;
+    typedef std::map<LLUUID, uuid_vec_t> requests_by_folders_t;
+    requests_by_folders_t requests;
 	for (uuid_vec_t::const_iterator it = mIDs.begin(); it < mIDs.end(); ++it)
 	{
         LLViewerInventoryItem* item = gInventory.getItem(*it);
@@ -335,12 +335,19 @@ void LLInventoryFetchItemsObserver::startFetch()
     if (aisv3)
     {
         const S32 MAX_INDIVIDUAL_REQUESTS = 10;
-        for (requests_by_fodlers_t::value_type &folder : requests)
+        for (requests_by_folders_t::value_type &folder : requests)
         {
+            LLViewerInventoryCategory* cat = gInventory.getCategory(folder.first);
             if (folder.second.size() > MAX_INDIVIDUAL_REQUESTS)
             {
                 // requesting one by one will take a while
                 // do whole folder
+                if (cat)
+                {
+                    // Either drop version or use scheduleFolderFetch to force-fetch
+                    // otherwise background fetch will ignore folders with set version
+                    cat->setVersion(LLViewerInventoryCategory::VERSION_UNKNOWN);
+                }
                 LLInventoryModelBackgroundFetch::getInstance()->start(folder.first);
             }
             else
@@ -355,7 +362,8 @@ void LLInventoryFetchItemsObserver::startFetch()
                     }
                     else if (cat->getViewerDescendentCount() <= folder.second.size())
                     {
                         // start fetching whole folder since we need all items
                         cat->setVersion(LLViewerInventoryCategory::VERSION_UNKNOWN);
                         cat->fetch();
 
@@ -355,7 +362,8 @@ void LLInventoryFetchItemsObserver::startFetch()
                     else if (cat->getViewerDescendentCount() <= folder.second.size())
                     {
-                        // start fetching whole folder since we need all items
+                        // Start fetching whole folder since we need all items
+                        // Drop version or use scheduleFolderFetch
                         cat->setVersion(LLViewerInventoryCategory::VERSION_UNKNOWN);
                         cat->fetch();